Tutorials
=========
Here we will list all tutorials for vermouth and Martinize 2.

.. Organize the tutorials in directories, so it's easier to keep their files
    together

.. toctree::
    1_simple_protein_aa/index
    2_simple_protein_cg/index
    3_membrane_protein/index
    4_branched_polymer/index
    5_glycosylated_protein/index
    6_adding_residues_links/index
    7_adding_modifications/index
